==> mdparse-0.10.tar.gz: mdparse-0.10/setup.py <==
from setuptools import setup
from setuptools import find_packages

setup(
    name='mdparse',
    packages=find_packages(),
    version='0.10',
    description='Parsing markdown files for deep learning.',
    author='Hamel Husain',
    author_email='hamel.husain@gmail.com',
    url='https://github.com/machine-learning-apps/mdparse',
    license='MIT',
    install_requires=['attrs>=19.1.0',
                      'backcall>=0.1.0',
                      'beautifulsoup4>=4.7.1',
                      'blis>=0.2.4',
                      'bs4>=0.0.1',
                      'cachetools>=3.1.1',
                      'chardet>=3.0.4',
                      'cymem>=2.0.2',
                      'cytoolz>=0.9.0.1',
                      'decorator>=4.4.0',
                      'certifi>=2019.3.9',
                      'html5lib>=1.0.1',
                      'idna>=2.8',
                      'jedi>=0.13.3',
                      'joblib>=0.13.2',
                      'jsonschema>=3.0.1',
                      'mistune>=0.8.4',
                      'murmurhash>=1.0.2',
                      'networkx>=2.3',
                      'numpy>=1.16.4',
                      'parso>=0.4.0',
                      'pickleshare>=0.7.5',
                      'plac>=0.9.6',
                      'preshed>=2.0.1',
                      'prompt-toolkit>=2.0.9',
                      'ptyprocess>=0.6.0',
                      'pyemd>=0.5.1',
                      'pygments>=2.4.2',
                      'pyphen>=0.9.5',
                      'pyrsistent>=0.15.2',
                      'python-dateutil>=2.8.0',
                      'python-levenshtein>=0.12.0',
                      'regex>=2019.6.8',
                      'requests>=2.22.0',
                      'six>=1.12.0',
                      'soupsieve>=1.9.1',
                      'spacy>=2.1.4',
                      'srsly>=0.0.7',
                      'textacy>=0.7.0',
                      'thinc>=7.0.4',
                      'timeout-decorator>=0.4.1',
                      'toolz>=0.9.0',
                      'tornado>=6.0.2',
                      'tqdm>=4.32.1',
                      'traitlets>=4.3.2',
                      'urllib3>=1.24.3',
                      'wasabi>=0.2.2',
                      'wcwidth>=0.1.7',
                      'webencodings>=0.5.1'],
    extras_require={
        'tests': ['pytest',
                  'pytest-pep8',
                  'pytest-xdist',
                  'pytest-cov'],
    },
    download_url='https://github.com/machine-learning-apps/mdparse/archive/0.10.zip',
    classifiers=[
        'Development Status :: 1 - Planning',
        'Programming Language :: Python :: 3.7',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)

==> mdparse-0.11.tar.gz: mdparse-0.11/setup.py <==
from setuptools import setup
from setuptools import find_packages

setup(
    name='mdparse',
    packages=find_packages(),
    version='0.11',
    description='Parsing markdown files for deep learning.',
    author='Hamel Husain',
    author_email='hamel.husain@gmail.com',
    url='https://github.com/machine-learning-apps/mdparse',
    license='MIT',
    install_requires=['attrs>=19.1.0',
                      'backcall>=0.1.0',
                      'beautifulsoup4>=4.7.1',
                      'blis>=0.2.4',
                      'bs4>=0.0.1',
                      'cachetools>=3.1.1',
                      'chardet>=3.0.4',
                      'cymem>=2.0.2',
                      'cytoolz>=0.9.0.1',
                      'decorator>=4.4.0',
                      'certifi>=2019.3.9',
                      'html5lib>=1.0.1',
                      'idna>=2.8',
                      'jedi>=0.13.3',
                      'joblib>=0.13.2',
                      'jsonschema>=3.0.1',
                      'mistune>=0.8.4',
                      'murmurhash>=1.0.2',
                      'networkx>=2.3',
                      'numpy>=1.16.4',
                      'parso>=0.4.0',
                      'pickleshare>=0.7.5',
                      'plac>=0.9.6',
                      'preshed>=2.0.1',
                      'prompt-toolkit>=2.0.9',
                      'ptyprocess>=0.6.0',
                      'pyemd>=0.5.1',
                      'pygments>=2.4.2',
                      'pyphen>=0.9.5',
                      'pyrsistent>=0.15.2',
                      'python-dateutil>=2.8.0',
                      'python-levenshtein>=0.12.0',
                      'regex>=2019.6.8',
                      'requests>=2.22.0',
                      'six>=1.12.0',
                      'soupsieve>=1.9.1',
                      'spacy>=2.1.4',
                      'srsly>=0.0.7',
                      'textacy>=0.7.0',
                      'thinc>=7.0.4',
                      'timeout-decorator>=0.4.1',
                      'toolz>=0.9.0',
                      'tornado>=6.0.2',
                      'tqdm>=4.32.1',
                      'traitlets>=4.3.2',
                      'urllib3>=1.24.3',
                      'wasabi>=0.2.2',
                      'wcwidth>=0.1.7',
                      'webencodings>=0.5.1'],
    extras_require={
        'tests': ['pytest',
                  'pytest-pep8',
                  'pytest-xdist',
                  'pytest-cov'],
    },
    download_url='https://github.com/machine-learning-apps/mdparse/archive/v.11.zip',
    classifiers=[
        'Development Status :: 1 - Planning',
        'Programming Language :: Python :: 3.7',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)
